BMI2xy Sensor API

> This package contains BMI2xy sensor API

## Sensor Overview
The BMI2xy is a small, low power, low noise inertial measurement unit designed for use in mobile applications like augmented reality or indoor navigation which require highly accurate, real-time sensor data.

### Features

- Indoor navigation, pedestrian dead-reckoning, step-counting

For more information refer product page [Link](https://www.bosch-sensortec.com/products/motion-sensors/imus/bmi270.html) 

---